"""add ql weblog caching

Revision ID: 85f659bf1425
Revises: 2dec906ab81a
Create Date: 2022-09-01 09:48:53.444085

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = "85f659bf1425"
down_revision = "675905a740c1"
branch_labels = None
depends_on = None


old_condor = """executable = vlass_ql_auto_qa.sh
arguments = {{manager_job_id}}

output = ql_auto_qa.out
error = ql_auto_qa.err
log = condor.log

should_transfer_files = NO

getenv = True
environment = "CAPO_PATH=/home/casa/capo"

requirements = HasLustre == True

queue

"""

old_script = """#!/bin/sh

source /lustre/aoc/cluster/pipeline/vlass_{{vlass_env}}/workspaces/bin/activate
export CAPO_PROFILE=vlass.{{vlass_env}}

JOB_ID=$1
printf "JOB_ID = %s
" $JOB_ID

cd working/
CASA_LOG_FILE=`ls casa-*.log`
../../../../workspaces/bin/annotateQa.py --jobid $JOB_ID $CASA_LOG_FILE

"""

condor = """executable = vlass_ql_auto_qa.sh
arguments = metadata.json {{manager_job_id}}

output = ql_auto_qa.out
error = ql_auto_qa.err
log = condor.log

should_transfer_files = NO

getenv = True
environment = "CAPO_PATH=/home/casa/capo"

requirements = HasLustre == True

queue

"""

script = """#!/bin/sh
set -o errexit

/lustre/aoc/cluster/pipeline/dsoc-{{vlass_env}}/workspaces/sbin/conveyor --vlass $1

source /lustre/aoc/cluster/pipeline/vlass_{{vlass_env}}/workspaces/bin/activate
export CAPO_PROFILE=vlass.{{vlass_env}}

JOB_ID=$2
printf "JOB_ID = %s
" $JOB_ID

cd working/
CASA_LOG_FILE=`ls casa-*.log`
../../../../workspaces/bin/annotateQa.py --jobid $JOB_ID $CASA_LOG_FILE

"""


def upgrade():
    op.execute(
        f"""
        UPDATE workflow_templates 
        SET content=E'{script}' WHERE filename='vlass_ql_auto_qa.sh'
        """
    )
    op.execute(
        f"""
        UPDATE workflow_templates 
        SET content=E'{condor}' WHERE filename='vlass_ql_auto_qa.condor'
        """
    )


def downgrade():
    op.execute(
        f"""
        UPDATE workflow_templates 
        SET content=E'{old_script}' WHERE filename='vlass_ql_auto_qa.sh'
        """
    )
    op.execute(
        f"""
            UPDATE workflow_templates 
            SET content=E'{old_condor}' WHERE filename='vlass_ql_auto_qa.condor'
            """
    )
