#
# Copyright (C) 2021 Associated Universities, Inc. Washington DC, USA.
#
# This file is part of NRAO Workspaces.
#
# Workspaces is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Workspaces is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.

""" Builds AMQP messages needed for capabilities """

# pylint: disable=E0401

import logging

from immutable_views import DictView

from workspaces.shared_interfaces import MessageArchitectIF

logger = logging.getLogger(__name__)

"""
Class which creates an immutable dictionary of amqp message templates for easy access
"""

# DictView(Dict[msg_type, msg_content]
service_templates = DictView(
    {
        "capability": {
            "service": "capability",
            "routing_key": "capability",
            "subject": None,
            "type": None,
        }
    }
)

# messages that require additional information, currently unneeded
# capability_msg_templates = DictView(
#     {
#         "cancel": {
#             "type": "cancel",
#         },
#     }
# )


class CapabilityMessageArchitect(MessageArchitectIF):
    """Creates messages needed used by capabilities"""

    def __init__(
        self,
        execution: "CapabilityExecution" = None,
        request: "CapabilityRequest" = None,
        version: "CapabilityVersion" = None,
    ):
        self.subject = execution or request or version

    @staticmethod
    def get_message_template(msg_type: str) -> dict:
        # If messages need additional information outside of the basic template,
        # uncomment this and add to relevant DictView
        # if msg_type in capability_msg_templates:
        #     return {**service_templates["capability"], **capability_msg_templates[msg_type]}
        # else:
        return service_templates["capability"]

    def compose_message(self, msg_type: str) -> DictView:
        template = self.get_message_template(msg_type)
        template = template.copy()

        template["subject"] = self.subject
        template["type"] = msg_type.replace("_", "-")
        return DictView(template)
